@@ -8,6 +8,8 @@ re_initial = re.compile(r'^(\w\.|[A-Z])?$', re.U)
 
 # do not include things that could also be first names, e.g. "dean"
 # many of these from wikipedia: https://en.wikipedia.org/wiki/Title
+# The parser recognizes chains of these including conjunctions allowing 
+# recognition titles like "Deputy Secretary of State"
 TITLES = set([
     'dr','doctor','miss','misses','mr','mister','mrs','ms','sir','dame',
     'rev','madam','madame','ab','2ndlt','amn','1stlt','a1c','capt','sra','maj',
@@ -27,7 +29,7 @@ TITLES = set([
     'foreign','minister','speaker','president','deputy','executive','vice',
     'councillor','alderman','delegate','mayor','lieutenant','governor','prefect',
     'prelate','premier','burgess','ambassador','envoy','secretary',u"attaché",
-    "chargé d'affaires",'provost',"marquis","marquess","marquise","marchioness",
+    u"chargé d'affaires",'provost',"marquis","marquess","marquise","marchioness",
     'archduke','archduchess','viscount','baron','emperor','empress','tsar',
     'tsarina','leader','abbess','abbot','brother','sister','friar','mother',
     'superior','reverend','bishop','archbishop','metropolitan','presbyter',
@@ -37,7 +39,7 @@ TITLES = set([
     'mufti','grand','chancellor','barrister','bailiff','attorney','advocate',
     'deacon','archdeacon','acolyte','elder','minister','monsignor','almoner',
     'prof','colonel','general','commodore','air','corporal','staff','mate',
-    'chief','first','sergeant','sergeant','admiral','high ','rear','brigadier',
+    'chief','first','sergeant','sergeant','admiral','high','rear','brigadier',
     'captain','group','commander','commander-in-chief','wing','general',
     'adjutant','director','generalissimo','resident','surgeon','officer',
     'academic','analytics','business','credit','financial','information',
@@ -49,30 +51,26 @@ TITLES = set([
     'bodhisattva','mullah','mahdi','saoshyant','tirthankar','vardapet',
     'pharaoh','emir','emira','sultan','sultana','maharajah','maharani','elder',
     'vizier','chieftain','comptroller','courtier','curator','doyen','edohen',
-    'ekegbian','elerunwon','forester ','gentiluomo','headman','intendant',
+    'ekegbian','elerunwon','forester','gentiluomo','headman','intendant',
     'lamido','marcher','matriarch','patriarch','prior','pursuivant','rangatira',
     'ranger','registrar','seigneur','sharif','shehu','sheikh','sheriff','subaltern',
     'subedar','sysselmann','timi','treasurer','verderer','warden','hereditary',
-    'woodman','bearer','banner','swordbearer','sayyid','apprentice','journeyman',
+    'woodman','bearer','banner','swordbearer','apprentice','journeyman',
     'adept','akhoond','arhat','bwana','goodman','goodwife','bard','hajji','mullah',
-    'sri','baba','effendi','giani','gyani','guru','siddha','pir','murshid',
-    'attache'
+    'baba','effendi','giani','gyani','guru','siddha','pir','murshid',
+    'attache','prime','united','states','national','associate','assistant',
 ])
 
-# QUESTIONABLE_TITLES could be last names or they could be titles.
-# TODO: need to find best way to deal with these, not doing anything special yet.
-# http://code.google.com/p/python-nameparser/issues/detail?id=3
-QUESTIONABLE_TITLES = ('judge',)
-
 # PUNC_TITLES could be names or titles, but if they have period at the end they're a title
 PUNC_TITLES = ('hon.',)
 
 # words that prefix last names. Can be chained like "de la Vega"
-PREFICES = set([
-    'abu','bon','ben','bin','da','dal','de','del','der','de','di',u'dí','ibn',
+# these should not be more common as first or middle names than prefixes
+PREFIXES = set([
+    'abu','bon','bin','da','dal','de','del','der','de','di',u'dí','ibn',
     'la','le','san','st','ste','van','vel','von'
 ])
-SUFFICES = set([
+SUFFIXES = set([
     'esq','esquire','jr','sr','2','i','ii','iii','iv','v','clu','chfc',
     'cfp','md','phd'
 ])
@@ -85,3 +83,6 @@ CAPITALIZATION_EXCEPTIONS = (
 )
 CONJUNCTIONS = set(['&','and','et','e','of','the','und','y',])
 
+# pre v0.2.5 support
+PREFICES = PREFIXES 
+SUFFICES = SUFFIXES
