@@ -5,7 +5,13 @@ from constants import *
 
 # http://code.google.com/p/python-nameparser/issues/detail?id=10
 log = logging.getLogger('HumanName')
-log.addHandler(logging.NullHandler())
+try:
+    log.addHandler(logging.NullHandler())
+except AttributeError:
+    class NullHandler(logging.Handler):
+        def emit(self, record):
+            pass
+    log.addHandler(NullHandler())
 log.setLevel(logging.ERROR)
 
 ENCODING = 'utf-8'
